<?php
/**
 * Add Board meta data
 * This includes adding an image upload field
 * And displaying shortcodes to Boards
 *
 * @since 1.5.0
 */

// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Plugin class
 **/
if( ! class_exists( 'CT_DB_Pro_Admin_Boards' ) ) {

	class CT_DB_Pro_Admin_Boards {

		public function __construct() {
			//
		}
		
		/**
		 * Initialize the class and start calling our hooks and filters
		 * @since 1.5.0
		 */
		public function init() {
			// Image actions
			add_action( 'board_add_form_fields', array( $this, 'add_category_image' ), 10, 2 );
			add_action( 'created_board', array( $this, 'save_category_image' ), 10, 2 );
			add_action( 'board_edit_form_fields', array( $this, 'update_category_image' ), 10, 2 );
			add_action( 'edited_board', array( $this, 'updated_category_image' ), 10, 2 );
			add_action( 'admin_enqueue_scripts', array( $this, 'load_media' ) );
			add_action( 'admin_footer', array( $this, 'add_script' ) );
			
			// Board followers actions
			add_action( 'board_edit_form_fields', array( $this, 'update_board_followers' ), 10, 2 );
			add_action( 'edited_board', array( $this, 'updated_board_followers' ), 10, 2 );
			
			// Shortcode actions
			add_action( 'board_edit_form_fields', array( $this, 'update_shortcode_field' ), 10, 2 );
			
			// Column filters
			add_filter( 'manage_edit-board_columns', array( $this, 'add_new_columns' ) );
			add_filter( 'manage_board_custom_column', array( $this, 'manage_new_columns' ), 10, 3 );
		}
		
		public function load_media() {
			if( ! isset( $_GET['taxonomy'] ) || $_GET['taxonomy'] != 'board' ) {
				return;
			}
			wp_enqueue_media();
		}
	
		
		/**
		 * Add a column for shortcodes
		 * @since 1.5.2
		 */
		public function add_new_columns( $columns ) {
			$columns['shortcode'] = __( 'Shortcode', 'discussion-board-pro' );
			return $columns;
		}
		
		/**
		 * Add shortcodes to column
		 * @since 1.5.2
		 */
		public function manage_new_columns( $value, $name, $id ) {
			if( $name == 'shortcode' ) {
				$shortcode = $this->build_shortcode( $id );
				return $shortcode;
			}
			return $value;
		}
		
		/**
		 * Add shortcodes to column
		 * @since 1.5.2
		 */
		public function build_shortcode( $id ) {
			$shortcode = 'discussion_board';
			if( $id ) {
				$shortcode .= ' board=' . $id;
			}
			return '[' . esc_attr( $shortcode ) . ']';
		}
		
		/**
		 * Edit the form field
		 * @since 1.5.0
		 */
		public function update_shortcode_field( $term, $taxonomy ) { ?>
			<tr class="form-field term-group-wrap">
				<th scope="row">
					<label for="ct_db_pro_board_shortcode"><?php _e( 'Shortcode', 'discussion-board-pro' ); ?></label>
				</th>
				<td>
					<?php // Build shortcode 
					$shortcode = $this->build_shortcode( $term->term_id );
					?>
					<input type="text" readonly style="width: 300px;" id="ct_db_pro_board_shortcode" name="ct_db_pro_board_shortcode" value="<?php echo esc_attr( $shortcode ); ?>">
					<p class="description"><?php _e( 'Copy this shortcode and paste it into the page where you would like to display this Board', 'discussion-board-pro' ); ?></p>
				</td>
			</tr>
		<?php
		}
		
		/**
		 * Edit the form field for board_followers
		 * @since 1.6.2
		 */
		public function update_board_followers( $term, $taxonomy ) { ?>
			<tr style="display: none;">
				<td>
					<?php $followers = get_term_meta( $term->term_id, 'ctdb_board_followers', true ); ?>
					<input type="hidden" style="width: 300px;" id="ctdb_board_followers" name="ctdb_board_followers" value="<?php echo esc_attr( $followers ); ?>">
				</td>
			</tr>
		<?php
		}
		
		/**
		 * Update the form field value for board_followers
		 * @since 1.6.2
		 */
		public function updated_board_followers( $term_id, $tt_id ) {
			if( isset( $_POST['ctdb_board_followers'] ) && '' !== $_POST['ctdb_board_followers'] ) {
				$followers = $_POST['ctdb_board_followers'];
				$followers = explode( ',', $_POST['ctdb_board_followers'] );
				$clean_followers = array();
				if( is_array( $followers ) ) {
					// Make sure we sanitize each email address
					foreach( $followers as $follower ) {
						$clean_followers[] = sanitize_email( $follower );
					}
				}
				$followers = join( ',', $clean_followers );
				update_term_meta( $term_id, 'ctdb_board_followers', $followers );
			} else {
				update_term_meta( $term_id, 'ctdb_board_followers', '' );
			}
		}		
		
		/**
		 * Add a form field in the new category page
		 * @since 1.5.0
		 */
		public function add_category_image( $taxonomy ) { ?>
			<div class="form-field term-group">
				<label for="ctdb-board-image-id"><?php _e( 'Image', 'discussion-board-pro' ); ?></label>
				<input type="hidden" id="ctdb-board-image-id" name="ctdb-board-image-id" class="custom_media_url" value="">
				<div id="category-image-wrapper"></div>
				<p>
					<input type="button" class="button button-secondary ct_tax_media_button" id="ct_tax_media_button" name="ct_tax_media_button" value="<?php _e( 'Add Image', 'discussion-board-pro' ); ?>" />
					<input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php _e( 'Remove Image', 'discussion-board-pro' ); ?>" />
				</p>
			</div>
			
			<?php // Check against board specific rules first
			$plan = ctdb_get_license_plan();
			if( $plan == 'developer' || $plan == 'unlimited' ) {
				// We can only do board-specific permissions on developer and unlimited plans ?>
				<div class="form-field term-group">
					<label for="viewer_roles"><?php _e( 'Permitted viewer roles', 'discussion-board-pro' ); ?></label>
					<p>
						<select multiple='multiple' id="viewer_roles" name="viewer_roles[]">
							<?php $roles = get_editable_roles();
							foreach( $roles as $rolename => $role ) {
								// Pending should never be able to post
								// Admins will always be able to post
								if( $rolename != 'pending' && $rolename != 'administrator' ) { ?>
									<option value='<?php echo $rolename; ?>'><?php echo $role['name']; ?></option>
								<?php }
							} ?>
						</select>
					</p>
					<p class="description"><?php _e( 'Decide who can view and reply to topics in this board. Admins can always view.', 'discussion-board-pro' ); ?></p>
				</div>
			
				<div class="form-field term-group">
					<label for="poster_roles"><?php _e( 'Permitted poster roles', 'discussion-board-pro' ); ?></label>
					<p>
						<select multiple='multiple' id="poster_roles" name="poster_roles[]">
							<?php $roles = get_editable_roles();
							foreach( $roles as $rolename => $role ) {
								// Pending should never be able to post
								if( $rolename != 'pending' ) { ?>
									<option value='<?php echo $rolename; ?>'><?php echo $role['name']; ?></option>
								<?php }
							} ?>
						</select>
					</p>
					<p class="description"><?php _e( 'Decide who can post new topics in this board.', 'discussion-board-pro' ); ?></p>
				</div>
			<?php } else { ?>
				<div class="form-field term-group">
					<label for="poster_roles_disabled"><?php _e( 'Permitted poster roles', 'discussion-board-pro' ); ?></label>
					<p>
						<select disabled multiple='multiple' id="poster_roles_disabled" name="poster_roles_disabled[]">
							<?php $roles = get_editable_roles();
							foreach( $roles as $rolename => $role ) {
								// Pending should never be able to post
								if( $rolename != 'pending' ) { ?>
									<option value='<?php echo $rolename; ?>'><?php echo $role['name']; ?></option>
								<?php }
							} ?>
						</select>
					</p>
					<p class="description">
						<?php printf( '<a href="%s" target="_blank">%s</a>',
							esc_url( trailingslashit( CT_DB_PRO_STORE_URL ) . 'checkout/purchase-history/' ),
							__( 'Upgrade to a developer or unlimited license plan to use this feature.', 'discussion-board-pro' )
						); ?>
					</p>
				</div>
			<?php } ?>
			
			<div class="form-field term-group">
				<label for="ctdb-board-permissions"><?php _e( 'Restrictions', 'discussion-board-pro' ); ?></label>
				<p>
					<select id="ctdb-board-permissions" name="ctdb-board-permissions">
						<?php $options = ctdb_get_board_permission_options(); 
						foreach( $options as $key=>$value ) { ?>
							<option value="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $value ); ?></option>
						<?php } ?>
					</select>
				</p>
				<p class="description"><?php _e( 'Set additional restrictions on viewing and posting', 'discussion-board-pro' ); ?></p>
			</div>
			
		<?php
		}
		
		/**
		 * Save the form field
		 * @since 1.5.0
		 */
		public function save_category_image( $term_id, $tt_id ) {
			if( isset( $_POST['ctdb-board-image-id'] ) && '' !== $_POST['ctdb-board-image-id'] ) {
				add_term_meta( $term_id, 'ctdb-board-image-id', absint( $_POST['ctdb-board-image-id'] ), true );
			}
			if( isset( $_POST['viewer_roles'] ) && '' !== $_POST['viewer_roles'] ) {
				$roles = array();
				if( is_array( $_POST['viewer_roles'] ) ) {
					foreach( $_POST['viewer_roles'] as $key=>$value ) {
						$roles[] = sanitize_text_field( $value );
					}
				}
				add_term_meta( $term_id, 'viewer_roles', $roles, true );
			}
			if( isset( $_POST['poster_roles'] ) && '' !== $_POST['poster_roles'] ) {
				$roles = array();
				if( is_array( $_POST['poster_roles'] ) ) {
					foreach( $_POST['poster_roles'] as $key=>$value ) {
						$roles[] = sanitize_text_field( $value );
					}
				}
				add_term_meta( $term_id, 'poster_roles', $roles, true );
			}
			if( isset( $_POST['ctdb-board-permissions'] ) && '' !== $_POST['ctdb-board-permissions'] ) {
				add_term_meta( $term_id, 'ctdb-board-permissions', sanitize_text_field( $_POST['ctdb-board-permissions'] ), true );
			}
		}
		
		/**
		 * Edit the form field
		 * @since 1.5.0
		 */
		public function update_category_image( $term, $taxonomy ) { ?>
			<tr class="form-field term-group-wrap">
				<th scope="row">
					<label for="ctdb-board-image-id"><?php _e( 'Image', 'discussion-board-pro' ); ?></label>
				</th>
				<td>
					<?php $image_id = get_term_meta( $term->term_id, 'ctdb-board-image-id', true ); ?>
					<input type="hidden" id="ctdb-board-image-id" name="ctdb-board-image-id" value="<?php echo esc_attr( $image_id ); ?>">
					<div id="category-image-wrapper">
						<?php if( $image_id ) { ?>
							<?php echo wp_get_attachment_image( $image_id, 'thumbnail' ); ?>
						<?php } ?>
					</div>
					<p>
						<input type="button" class="button button-secondary ct_tax_media_button" id="ct_tax_media_button" name="ct_tax_media_button" value="<?php _e( 'Add Image', 'discussion-board-pro' ); ?>" />
						<input type="button" class="button button-secondary ct_tax_media_remove" id="ct_tax_media_remove" name="ct_tax_media_remove" value="<?php _e( 'Remove Image', 'discussion-board-pro' ); ?>" />
					</p>
				</td>
			</tr>
			
			<?php // Check against board specific rules first
			$plan = ctdb_get_license_plan();
			if( $plan == 'developer' || $plan == 'unlimited' ) {
				// We can only do board-specific permissions on developer and unlimited plans ?>
				<tr class="form-field term-group-wrap">
					<th scope="row">
						<label for="viewer_roles"><?php _e( 'Permitted viewer roles', 'discussion-board-pro' ); ?></label>
					</th>
					<td>
						<?php $viewer_roles = get_term_meta( $term->term_id, 'viewer_roles', true ); ?>
						<p>
							<select multiple='multiple' id="viewer_roles" name="viewer_roles[]">
								<?php $roles = get_editable_roles();
								foreach( $roles as $rolename => $role ) {
									// Pending should never be able to post
									// Admins will always be able to post
									if( $rolename != 'pending' && $rolename != 'administrator' ) {
										$selected = '';
										//Check for selected values
										if( count( $viewer_roles ) > 0 ) {
											if( in_array( $rolename, $viewer_roles ) ? $selected = 'selected' : $selected = '' );
										} ?>
										<option value='<?php echo $rolename; ?>' <?php echo $selected; ?>><?php echo $role['name']; ?></option>
									<?php }
								} ?>
							</select>
						
						
						</p>
						<p class="description"><?php _e( 'Decide who can view and reply to topics in this board. Admins can always view.', 'discussion-board-pro' ); ?></p>
					</td>
				</tr>
			
				<tr class="form-field term-group-wrap">
					<th scope="row">
						<label for="poster_roles"><?php _e( 'Permitted poster roles', 'discussion-board-pro' ); ?></label>
					</th>
					<td>
						<?php $poster_roles = get_term_meta( $term->term_id, 'poster_roles', true ); ?>
						<p>
							<select multiple='multiple' id="poster_roles" name="poster_roles[]">
								<?php $roles = get_editable_roles();
								foreach( $roles as $rolename=>$role ) {
									// Pending should never be able to post
									if( $rolename != 'pending' ) {
										$selected = '';
										//Check for selected values
										if( count( $poster_roles ) > 0 ) {
											if( in_array( $rolename, $poster_roles ) ? $selected = 'selected' : $selected = '' );
										} ?>
										<option value='<?php echo $rolename; ?>' <?php echo $selected; ?>><?php echo $role['name']; ?></option>
									<?php }
								} ?>
							</select>
						
						</p>
						<p class="description"><?php _e( 'Decide who can post new topics in this board.', 'discussion-board-pro' ); ?></p>
					</td>
				</tr>
			<?php } else { ?>
				<tr class="form-field term-group-wrap">
					<th scope="row">
						<label for="disabled_poster_roles"><?php _e( 'Permitted poster roles', 'discussion-board-pro' ); ?></label>
					</th>
					<td>
						<?php $poster_roles = get_term_meta( $term->term_id, 'poster_roles', true ); ?>
						<p>
							<select disabled multiple='multiple' id="disabled_poster_roles" name="disabled_poster_roles[]">
								<?php $roles = get_editable_roles();
								foreach( $roles as $rolename=>$role ) {
									// Pending should never be able to post
									if( $rolename != 'pending' ) {
										$selected = '';
										//Check for selected values
										if( count( $poster_roles ) > 0 ) {
											if( in_array( $rolename, $poster_roles ) ? $selected = 'selected' : $selected = '' );
										} ?>
										<option value='<?php echo $rolename; ?>' <?php echo $selected; ?>><?php echo $role['name']; ?></option>
									<?php }
								} ?>
							</select>
						
						</p>
						<p class="description">
							<?php printf( '<a href="%s" target="_blank">%s</a>',
								esc_url( trailingslashit( CT_DB_PRO_STORE_URL ) . 'checkout/purchase-history/' ),
								__( 'Upgrade to a developer or unlimited license plan to use this feature.', 'discussion-board-pro' )
							); ?>
						</p>
					</td>
				</tr>
			<?php } ?>
			
			<tr class="form-field term-group-wrap">
				<th scope="row">
					<label for="ctdb-board-permissions"><?php _e( 'Restrictions', 'discussion-board-pro' ); ?></label>
				</th>
				<td>
					<?php $permissions = get_term_meta( $term->term_id, 'ctdb-board-permissions', true ); ?>
					<p>
						<select id="ctdb-board-permissions" name="ctdb-board-permissions">
							<?php $options = ctdb_get_board_permission_options(); 
							foreach( $options as $key=>$value ) { ?>
								<option <?php selected( $key, $permissions, true ); ?>  value="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $value ); ?></option>
							<?php } ?>
						</select>
					</p>
					<p class="description"><?php _e( 'Set additional restrictions on viewing and posting', 'discussion-board-pro' ); ?></p>
				</td>
			</tr>
		<?php
		}

		/**
		 * Update the form field value
		 * @since 1.5.0
		 */
		public function updated_category_image( $term_id, $tt_id ) {
			if( isset( $_POST['ctdb-board-image-id'] ) && '' !== $_POST['ctdb-board-image-id'] ){
				update_term_meta( $term_id, 'ctdb-board-image-id', absint( $_POST['ctdb-board-image-id'] ) );
			} else {
				update_term_meta( $term_id, 'ctdb-board-image-id', '' );
			}
			if( isset( $_POST['viewer_roles'] ) && '' !== $_POST['viewer_roles'] ) {
				$roles = array();
				if( is_array( $_POST['viewer_roles'] ) ) {
					foreach( $_POST['viewer_roles'] as $key=>$value ) {
						$roles[] = sanitize_text_field( $value );
					}
				}
				update_term_meta( $term_id, 'viewer_roles', $roles );
			} else {
				update_term_meta( $term_id, 'viewer_roles', '' );
			}
			if( isset( $_POST['poster_roles'] ) && '' !== $_POST['poster_roles'] ) {
				$roles = array();
				if( is_array( $_POST['poster_roles'] ) ) {
					foreach( $_POST['poster_roles'] as $key=>$value ) {
						$roles[] = sanitize_text_field( $value );
					}
				}
				update_term_meta( $term_id, 'poster_roles', $roles );
			} else {
				update_term_meta( $term_id, 'poster_roles', '' );
			}
			if( isset( $_POST['ctdb-board-permissions'] ) && '' !== $_POST['ctdb-board-permissions'] ){
				update_term_meta( $term_id, 'ctdb-board-permissions', sanitize_text_field( $_POST['ctdb-board-permissions'] ) );
			} else {
				update_term_meta( $term_id, 'ctdb-board-permissions', '' );
			}
		}

		/**
		 * Enqueue styles and scripts
		 * @since 1.5.0
		 */
		public function add_script() {
			if( ! isset( $_GET['taxonomy'] ) || $_GET['taxonomy'] != 'board' ) {
				return;
			} ?>
			<script>
				jQuery(document).ready( function($) {
					_wpMediaViewsL10n.insertIntoPost = '<?php _e( "Insert into Board", "discussion-board-pro" ); ?>';
					function ct_media_upload(button_class) {
						var _custom_media = true,
						_orig_send_attachment = wp.media.editor.send.attachment;
						$('body').on('click', button_class, function(e) {
							var button_id = '#'+$(this).attr('id');
							var send_attachment_bkp = wp.media.editor.send.attachment;
							var button = $(button_id);
							_custom_media = true;
							wp.media.editor.send.attachment = function(props, attachment){
								if( _custom_media ) {
									$('#ctdb-board-image-id').val(attachment.id);
									$('#category-image-wrapper').html('<img class="custom_media_image" src="" style="margin:0;padding:0;max-height:100px;float:none;" />');
									$('#category-image-wrapper .custom_media_image').attr('src',attachment.sizes.thumbnail.url).css('display','block');
								} else {
									return _orig_send_attachment.apply( button_id, [props, attachment] );
								}
							}
							wp.media.editor.open(button);
							return false;
						});
					}
					ct_media_upload('.ct_tax_media_button.button');				
					$('body').on('click','.ct_tax_media_remove',function(){
						$('#ctdb-board-image-id').val('');
						$('#category-image-wrapper').html('<img class="custom_media_image" src="" style="margin:0;padding:0;max-height:100px;float:none;" />');
					});
					// Thanks: http://stackoverflow.com/questions/15281995/wordpress-create-category-ajax-response
					$(document).ajaxComplete(function(event, xhr, settings) {
						var queryStringArr = settings.data.split('&');
						if( $.inArray('action=add-tag', queryStringArr) !== -1 ){
							var xml = xhr.responseXML;
							$response = $(xml).find('term_id').text();
							if($response!=""){
								// Clear the thumb image
								$('#category-image-wrapper').html('');
							}
						}
					});
				});
			</script>
		<?php }

	}
	
	$CT_DB_Pro_Admin_Boards = new CT_DB_Pro_Admin_Boards();
	$CT_DB_Pro_Admin_Boards->init();
	
}