<?php
/*
 * Additional data for the Pro version
 *
 * @since 1.5.2
 */

// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Returns an array of settings for the General tab
 * This is partial at the moment
 *
 * @since 2.1.0
 * @return Array
 * @todo add remaining settings to this array
 */
if( ! function_exists( 'ctdb_pro_general_page_settings' ) ) {
	function ctdb_pro_general_page_settings( $settings ) {
		$settings['board_page'] = array(
			'id'			=> 'board_page',
			'label'			=> __( 'Board page', 'discussion-board-pro' ),
			'callback'		=> 'pages_select_callback',
			'description'	=> __( 'The page where you display your Boards (if enabled). This page should contain at least one [discussion_board] shortcode.', 'discussion-board-pro' ),
			'page'			=> 'ctdb_options',
			'section'		=> 'ctdb_options_settings',
		);
		$settings['pro_breadcrumbs_heading'] = array(
			'id'		=> 'pro_breadcrumbs_heading',
			'label'		=> '<h3>' . __( 'Breadcrumbs', 'discussion-board-pro' ) . '</h3>',
			'callback'	=> 'page_header_callback',
			'page'		=> 'ctdb_options',
			'section'	=> 'ctdb_options_settings',
		);
		$settings['enable_breadcrumbs'] = array(
			'id'			=> 'enable_breadcrumbs',
			'label'			=> __( 'Enable Breadcrumbs', 'discussion-board-pro' ),
			'callback'		=> 'checkbox_callback',
			'description'	=> __( 'Add a breadcrumb navigation.', 'discussion-board-pro' ),
			'page'			=> 'ctdb_options',
			'section'		=> 'ctdb_options_settings',
		);
		$settings['breadcrumbs_format'] = array(
			'id'			=> 'breadcrumbs_format',
			'label'			=> __( 'Breadcrumbs Format', 'discussion-board-pro' ),
			'callback'		=> 'select_callback',
			'choices'		=> array(
				'short-board'	=> __( 'Board > Topic', 'discussion-board-pro' ),
				'std-board'		=> __( 'Boards > Board > Topic', 'discussion-board-pro' ),
				'home-board'	=> __( 'Home > Boards > Board > Topic', 'discussion-board-pro' ),
				'std-topics'	=> __( 'Topics > Topic', 'discussion-board-pro' ),
				'home-topics'	=> __( 'Home > Topics > Topic', 'discussion-board-pro' )
			),
			'description'	=> __( 'Define the pages to include in the breadcrumb.', 'discussion-board-pro' ),
			'page'			=> 'ctdb_options',
			'section'		=> 'ctdb_options_settings',
		);
		$settings['use_archive_in_breadcrumb'] = array(
			'id'			=> 'use_archive_in_breadcrumb',
			'label'			=> __( 'Use Topics Archive Page', 'discussion-board-pro' ),
			'callback'		=> 'checkbox_callback',
			'description'	=> __( 'Replace the Discussion Topics page with the Discussion Topics archive page.', 'discussion-board-pro' ),
			'page'			=> 'ctdb_options',
			'section'		=> 'ctdb_options_settings',
		);
		return $settings;
	}
	add_filter( 'ctdb_general_page_settings', 'ctdb_pro_general_page_settings' );
}

/**
 * Filter the User settings
 *
 * @since 1.7.0
 * @return Array
 */
if( ! function_exists( 'ctdb_pro_get_user_settings' ) ) {
	function ctdb_pro_get_user_settings( $settings ) {
		$license_limit = get_option( 'ct_db_pro_license_level' );
		if( false === $license_limit || 1 == $license_limit ) {
			// return $settings;
		}

		$settings['require_activation'] = array(
			'id'			=> 'require_activation',
			'label'			=> __( 'Require account activation', 'wp-discussion-board' ),
			'callback'		=> 'select_callback',
			'description'	=> __( 'Choose "User must activate" to require new users to click an activation link before they are fully registered. Choose "Admin" must approve to require admins to approve all new registrations.', 'wp-discussion-board' ),
			'choices'		=> array(
				'none'		=> __( 'None', 'discussion-board-pro' ),
				'user'		=> __( 'User must activate', 'discussion-board-pro' ),
				'admin'		=> __( 'Admin must approve', 'discussion-board-pro' ),
			),
			'page'			=> 'ctdb_user',
			'section'		=> 'ctdb_user_settings',
		);
		return $settings;
	}
	add_filter( 'ctdb_filter_user_settings', 'ctdb_pro_get_user_settings' );
}

/**
 * Returns an array of settings for the Pro tab
 * This is partial at the moment
 *
 * @since 1.5.3
 * @returns Array
 * @todo add remaining settings to this array
 */
if( ! function_exists( 'ctdb_pro_settings' ) ) {
	function ctdb_pro_settings() {
		$settings = array(
			'include_image_upload' => array(
				'id'			=> 'include_image_upload',
				'label'			=> __( 'Upload featured image', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Allow posters to upload featured image to topic. You should be very careful about allowing users to upload images to topics because of potential security risks. It is strongly recommended that only registered users should be allowed to post content when image uploads are permitted and even then you should proceed with caution. Currently, only png and jpg file types are permitted.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'use_editor' => array(
				'id'			=> 'use_editor',
				'label'			=> __( 'Enable editor', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Enable the WYSIWYG editor in the new topic form.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'enable_media_button' => array(
				'id'			=> 'enable_media_button',
				'label'			=> __( 'Allow media button', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Add the media button to the editor. Requires the "Enable editor" setting above to be selected. Please also note the comments on allowing users to upload images above.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'enable_comments_tinymce' => array(
				'id'			=> 'enable_comments_tinymce',
				'label'			=> __( 'Enable editor in comments', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Enable a simple WYSIWYG editor for comments.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			/*
			'enable_media_comments' => array(
				'id'			=> 'enable_media_comments',
				'label'			=> __( 'Allow media button in comment form', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Add the media button to the comment form. Requires the "Enable editor in comments" setting above to be selected. Please also note the comments on allowing users to upload images above.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			), */
			'always_allow_comments' => array(
				'id'			=> 'always_allow_comments',
				'label'			=> __( 'Always allow comments', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Remove the need to moderate comments - this will bypass your settings in Settings > Discussion. Any user with the correct permissions can post comments without moderation.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'pro_time_heading' => array(
				'id'		=> 'pro_time_heading',
				'label'		=> '<h3>' . __( 'Time', 'discussion-board-pro' ) . '</h3>',
				'callback'	=> 'page_header_callback',
				'page'		=> 'ctdb_pro',
				'section'	=> 'ctdb_pro_settings',
			),
			'time_format' => array(
				'id'			=> 'time_format',
				'label'			=> __( 'Time format', 'discussion-board-pro' ),
				'callback'		=> 'select_callback',
				'choices'		=> array(
					'standard'	=> __( 'Standard', 'discussion-board-pro' ),
					'freshness'	=> __( 'Freshness', 'discussion-board-pro' )
				),
				'description'	=> __( 'Define time and date format for comments and post date.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'freshness_time_format' => array(
				'id'			=> 'freshness_time_format',
				'label'			=> __( 'Freshness time format', 'discussion-board-pro' ),
				'callback'		=> 'select_callback',
				'choices'		=> array(
					'standard'	=> __( 'Standard', 'discussion-board-pro' ),
					'freshness'	=> __( 'Freshness', 'discussion-board-pro' )
				),
				'description'	=> __( 'Define time and date format for latest activity fields.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'pro_status_heading' => array(
				'id'		=> 'pro_status_heading',
				'label'		=> '<h3>' . __( 'Status', 'discussion-board-pro' ) . '</h3>',
				'callback'	=> 'page_header_callback',
				'page'		=> 'ctdb_pro',
				'section'	=> 'ctdb_pro_settings',
			),
			'status_scope' => array(
				'id'			=> 'status_scope',
				'label'			=> __( 'Status scope', 'discussion-board-pro' ),
				'callback'		=> 'select_callback',
				'choices'		=> array(
					'board'		=> __( 'Board', 'discussion-board-pro' ),
					'global'	=> __( 'Global', 'discussion-board-pro' )
				),
				'description'	=> __( 'You can have different statuses per Board or use a single, global setting.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'default_statuses' => array(
				'id'			=> 'default_statuses',
				'label'			=> __( 'Statuses', 'discussion-board-pro' ),
				'callback'		=> 'text_callback',
				'description'	=> __( 'Comma-separated list of statuses. Put your default value first, e.g. <code>Open, Fixed</code>. Only applies if you have Enable status above set to Global. Otherwise, set your statuses in Boards.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'poster_set_status' => array(
				'id'			=> 'poster_set_status',
				'label'			=> __( 'Poster can set status', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Allow the poster to set the status on the New Topic form (if the Status scope above is set to Global). Leave disabled for the default status to always be set on new topics.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
			'status_updaters' => array(
				'id'			=> 'status_updaters',
				'label'			=> __( 'Status updater', 'discussion-board-pro' ),
				'callback'		=> 'select_callback',
				'choices'		=> array(
					'op'			=> __( 'Original Poster', 'discussion-board-pro' ),
					'contributor'	=> __( 'Any Contributor', 'discussion-board-pro' )
				),
				'description'	=> __( 'Define who has permission to update a topic\'s status - either the user who posted the topic or any user who has contributed to the topic.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_pro',
				'section'		=> 'ctdb_pro_settings',
			),
		);
		$settings = apply_filters( 'ctdb_pro_settings', $settings );

		return $settings;
	}
}

/**
 * Returns an array of settings for the Followers tab
 *
 * @since 1.6.2
 * @return Array
 */
if( ! function_exists( 'ctdb_followers_settings' ) ) {
	function ctdb_followers_settings() {
		$settings = array(
			'enable_topic_following' => array(
				'id'			=> 'enable_topic_following',
				'label'			=> __( 'Enable topic following', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Allow users to subscribe to topics.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_followers',
				'section'		=> 'ctdb_followers_settings',
			),
			'display_follower_numbers' => array(
				'id'			=> 'display_follower_numbers',
				'label'			=> __( 'Enable follower numbers', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Display number of followers per topic.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_followers',
				'section'		=> 'ctdb_followers_settings',
			),
			'display_all_user_followers' => array(
				'id'			=> 'display_all_user_followers',
				'label'			=> __( 'Public followed topics', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'If the Followers tab is enabled in Profiles, select this option to make all users followed topics public.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_followers',
				'section'		=> 'ctdb_followers_settings',
			),
			'enable_board_following' => array(
				'id'			=> 'enable_board_following',
				'label'			=> __( 'Enable board following', 'discussion-board-pro' ),
				'callback'		=> 'checkbox_callback',
				'description'	=> __( 'Allow users to subscribe to boards and receive notifications on all topics within that board. Boards must be enabled.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_followers',
				'section'		=> 'ctdb_followers_settings',
			),
		);

		$settings = apply_filters( 'ctdb_followers_settings', $settings );

		return $settings;
	}
}

/**
 * Deprecated messages from the Followers tab
 * You can reinstate these by adding the following line to your functions.php file
 * add_filter( 'ctdb_followers_settings', 'ctdb_followers_messages_settings' );
 *
 * @since 1.6.2
 * @return Array
 */
if( ! function_exists( 'ctdb_followers_messages_settings' ) ) {

	function ctdb_followers_messages_settings( $settings ) {

		$messages_settings = array(
			'followers_messages_heading' => array(
				'id'		=> 'followers_messages_heading',
				'label'		=> '<h3>' . __( 'Messages', 'discussion-board-pro' ) . '</h3>',
				'callback'	=> 'page_header_callback',
				'page'		=> 'ctdb_followers',
				'section'	=> 'ctdb_followers_settings',
			),
			'follow_message' => array(
				'id'			=> 'follow_message',
				'label'			=> __( 'Enable topic following', 'discussion-board-pro' ),
				'callback'		=> 'wysiwyg_callback',
				'page'			=> 'ctdb_followers',
				'section'		=> 'ctdb_followers_settings',
			),
			'text_after_followers_message' => array(
				'id'			=> 'text_after_followers_message',
				'label'			=> __( 'After followers text', 'discussion-board-pro' ),
				'callback'		=> 'text_callback',
				'description'	=> __( 'Text to appear after follower count.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_followers',
				'section'		=> 'ctdb_followers_settings',
			),
			'button_follow_text' => array(
				'id'			=> 'button_follow_text',
				'label'			=> __( 'Button follow text', 'discussion-board-pro' ),
				'callback'		=> 'text_callback',
				'description'	=> __( 'Text to appear on the follow button - only enabled in some style layouts.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_followers',
				'section'		=> 'ctdb_followers_settings',
			),
			'button_unfollow_text' => array(
				'id'			=> 'button_unfollow_text',
				'label'			=> __( 'Button unfollow text', 'discussion-board-pro' ),
				'callback'		=> 'text_callback',
				'description'	=> __( 'Text to appear on the follow button - only enabled in some style layouts.', 'discussion-board-pro' ),
				'page'			=> 'ctdb_followers',
				'section'		=> 'ctdb_followers_settings',
			),

		);

		$settings = array_merge( $settings, $messages_settings );

		return $settings;
	}

}
