<?php
/*
 * Customizer
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/*
 * Array of Pro settings to be included in Customizer
 *
 * @returns Array
 * @since 1.6.4
 */
function ctdb_pro_customizer_settings() {
	$settings = array(
		'board_meta_border_color' 	=> array(
			'id'			=> 'board_meta_border_color',
			'label' 		=> __( 'Meta Border Color', 'wp-discussion-board' ),
			'section' 		=> 'ctdb_boards',
			'control'		=> 'color',
			'declaration' 	=> 'border-color',
			'element'		=> '.ctdb-board-wrapper'
		),
		'board_meta_color' 	=> array(
			'id'			=> 'board_meta_color',
			'label' 		=> __( 'Meta Text Color', 'wp-discussion-board' ),
			'section' 		=> 'ctdb_boards',
			'control'		=> 'color',
			'declaration' 	=> 'color',
			'element'		=> '.ctdb-board-wrapper'
		),
		'board_meta_link' 	=> array(
			'id'			=> 'board_meta_link',
			'label' 		=> __( 'Meta Link Color', 'wp-discussion-board' ),
			'section' 		=> 'ctdb_boards',
			'control'		=> 'color',
			'declaration' 	=> 'color',
			'element'		=> '.ctdb-board-wrapper a'
		),
		'board_footer_border_color'	=> array(
			'id'			=> 'board_footer_border_color',
			'label' 		=> __( 'Footer Border Color', 'wp-discussion-board' ),
			'section' 		=> 'ctdb_boards',
			'control'		=> 'color',
			'declaration' 	=> 'border-color',
			'element'		=> '.ctdb-board-topics-link'
		),
		'board_footer_background'	=> array(
			'id'			=> 'board_footer_background',
			'label' 		=> __( 'Footer Background Color', 'wp-discussion-board' ),
			'section' 		=> 'ctdb_boards',
			'control'		=> 'color',
			'declaration' 	=> 'background-color',
			'element'		=> '.ctdb-board-topics-link'
		),
		'board_footer_link'	=> array(
			'id'			=> 'board_footer_link',
			'label' 		=> __( 'Footer Link Color', 'wp-discussion-board' ),
			'section' 		=> 'ctdb_boards',
			'control'		=> 'color',
			'declaration' 	=> 'color',
			'element'		=> '.ctdb-board-topics-link a'
		),
	);
	return $settings;
}


function ctdb_pro_customize_register( $wp_customize ) {

	$wp_customize -> add_section( 'ctdb_boards', array (
		'title'		=>	__( 'Boards', 'wp-discussion-board' ),
		'panel'		=> 'ctdb',
		'priority'	=> 	30
	) );
	
	$settings = ctdb_pro_customizer_settings();
	if( ! empty( $settings ) ) {
		foreach( $settings as $setting ) {
			// Layout settings
			$wp_customize -> add_setting( 'ctdb_design_settings[' . $setting['id'] . ']', array(
				'type' 					=> 'option', // or 'option'
				'capability' 			=> 'edit_theme_options',
				'theme_supports' 		=> '', // Rarely needed.
				'default' 				=> '',
				'transport'				=> 'refresh', // or postMessage
				'sanitize_callback' 	=> '',
				'sanitize_js_callback' 	=> '', // Basically to_json.
			) );
			$control_args =	array(
				'type' 					=> $setting['control'],
			//	'priority' 				=> 5, // Within the section.
				'section' 				=> $setting['section'], // Required, core or custom.
				'label' 				=> $setting['label'],
			);
			if( isset( $setting['choices'] ) ) {
				$control_args['choices'] = $setting['choices'];
			}
			if( isset( $setting['callback'] ) ) {
				$control_args['active_callback'] = $setting['callback'];
			}
			$wp_customize -> add_control( 'ctdb_design_settings[' . $setting['id'] . ']', $control_args );
		}
	}
}
add_action( 'customize_register', 'ctdb_pro_customize_register', 999 );